[PATCH] D134863: [LLVM][MC] Disable cfi-version test for aarch64-pc-windows*

Muhammad Omair Javaid via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Thu Sep 29 02:38:11 PDT 2022


This revision was landed with ongoing or failed builds.
This revision was automatically updated to reflect the committed changes.
Closed by commit rGf1c74f80c852: [LLVM][MC] Disable cfi-version test for aarch64-pc-windows* (authored by omjavaid).

Changed prior to commit:
  https://reviews.llvm.org/D134863?vs=463805&id=463811#toc

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D134863/new/

https://reviews.llvm.org/D134863

Files:
  llvm/test/MC/ELF/cfi-version.ll
  llvm/test/lit.cfg.py


Index: llvm/test/MC/ELF/cfi-version.ll
===================================================================
--- llvm/test/MC/ELF/cfi-version.ll
+++ llvm/test/MC/ELF/cfi-version.ll
@@ -6,7 +6,7 @@
 ; PR46647
 ; XFAIL: arm64-apple
 
-; .debug_frame is not emitted for targeting Windows x64, arm64, or AIX.
+; .debug_frame is not emitted for targeting Windows x64, aarch64/arm64, or AIX.
 ; REQUIRES: debug_frame
 ; REQUIRES: object-emission
 


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D134863.463811.patch
Type: text/x-patch
Size: 1163 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20220929/5ff44a94/attachment.bin>


More information about the llvm-commits mailing list
Index: llvm/test/lit.cfg.py
===================================================================
--- llvm/test/lit.cfg.py
+++ llvm/test/lit.cfg.py
@@ -436,8 +436,8 @@
         if 'hw.optional.fma: 1' in result:
             config.available_features.add('fma3')
 
-# .debug_frame is not emitted for targeting Windows x64, arm64, or AIX.
-if not re.match(r'^(x86_64|arm64|powerpc|powerpc64).*-(windows-gnu|windows-msvc|aix)', config.target_triple):
+# .debug_frame is not emitted for targeting Windows x64, aarch64/arm64, or AIX.
+if not re.match(r'^(x86_64|aarch64|arm64|powerpc|powerpc64).*-(windows-gnu|windows-msvc|aix)', config.target_triple):
     config.available_features.add('debug_frame')
 
 if config.have_libxar: